==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_articles.php <==
<?php
class Articles extends Admin {
	function __construct() {
		$this->pagePos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->h = New Html();
		$this->tr = New Translate();
	}
	private function sortArticleBy() {
		$type = isset($_POST['sorttype'])?$_POST['sorttype']:1;
		switch ($type) {
			case 1:
				$result = ARTICLES.".DATE DESC";
				break;
			case 2:
				$result = ARTICLES.".SUBJECT";
				break;
			case 3:
				$result = ARTICLES.".PAGEID";
				break;
			case 4:
				$result = ARTICLES.".USERID";;   
				break;
		}
		return $result;
	}
	public function update_articles() {
		// empty form
		if (count($_POST) == 1) return;
		
		$values = $_POST;
		foreach($values as $k=>$v) {
			if ( preg_match("/\_/",$k) ) {
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value) {
			$query = 0;
			if (isset($value['delete'])) {
				$query = "DELETE FROM ".ARTICLES." WHERE ID = ".$id;
				$query = $this->q($query);
			}
			if (isset($value['hide']) && $value['oldhide'] == 0) {
				$query = "UPDATE ".ARTICLES." SET HIDE = 1 WHERE ID = ".$id;
				$query = $this->q($query);
			} else if (!isset($value['hide']) && $value['oldhide'] == 1) {
				$query = "UPDATE ".ARTICLES." SET HIDE = 0 WHERE ID = ".$id;
				$query = $this->q($query);
			}
		}
		$result = "";
		return $result;
	}
	public function list_articles($pgPos) {
		if ($pgPos) $pgPos = ($pgPos - 1) * ADMINITEMSBYPAGE;
		$siteDat = $this->home_params();
		if (isset($_POST['search'])) {
			$queryLevel1 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							"MATCH(".ARTICLES.".SUBJECT) AGAINST('".$this->h->safe($_POST['search'])."') ".
							" ORDER BY ".ARTICLES.".SUBJECT LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							USERS.".USERLEVEL >= ".$_SESSION['level']." AND ".
							" MATCH(".ARTICLES.".SUBJECT) AGAINST('".$this->h->safe($_POST['search'])."') ".
							" ORDER BY ".ARTICLES.".SUBJECT LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".PAGES.".NAME FROM ".ARTICLES.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							"MATCH(".ARTICLES.".SUBJECT) AGAINST('".$this->h->safe($_POST['search'])."') ".
							" ORDER BY ".ARTICLES.".SUBJECT LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel4 = 	"SELECT ID,SUBJECT,DATE,HIDE FROM ".ARTICLES." WHERE ".
							ARTICLES.".PAGEID = ".$siteDat['SANDBOXID']." AND ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							"MATCH(".ARTICLES.".SUBJECT) AGAINST('".$this->h->safe($_POST['search'])."') ".
							" ORDER BY ".ARTICLES.".SUBJECT LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} else {
			$queryLevel1 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID".
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							USERS.".USERLEVEL >= ".$_SESSION['level'].
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".PAGES.".NAME FROM ".ARTICLES.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID".
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel4 = 	"SELECT ID,SUBJECT,DATE,HIDE FROM ".ARTICLES." WHERE ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							ARTICLES.".PAGEID = ".$siteDat['SANDBOXID']." ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		}
		
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3,$queryLevel4);
		$query = $queries[$_SESSION['level']];
		$query = $this->q($query);
		$modified = isset($_POST['update'])?$this->tr->w(", (some values have been modified !)"):null;
		$result = $this->h->h3($this->tr->w("articles list").$modified);
		
		$sort = array("date"=>1,"subject"=>2,"page"=>3,"user"=>4);
		$type = isset($_POST['sorttype'])?$_POST['sorttype']:1;
		$sortForm = $this->h->p($this->h->select($sort,"sorttype",$type)." ".$this->h->input("submit","",$this->tr->w("sort/group by")));
		$result .= $this->h->form($sortForm,"sort","post","admin.php?action=articles");
		
		$searchForm = $this->h->p($this->h->input("submit","",$this->tr->w("search subject"))." ".$this->h->input("text","search",""));
		$result .= $this->h->form($searchForm,"search","post","admin.php?action=articles");
		
		$artListSubmit = $this->h->p($this->h->input("submit","",$this->tr->w("update all")));
		$artList = $this->h->input("hidden","update",1);
		while ( $line = mysql_fetch_assoc($query) ) {
			$user = isset($line['USERNAME'])?$this->tr->w("{by-").$line['USERNAME']."}":null;
			$page = isset($line['NAME'])?"[".$line['NAME']."]":$this->tr->wsp("{page-SandBox}");
			$date = $line['DATE'];
			$hideParams = ($line['HIDE'])?" checked=\"checked\"":null;
			$hide = $this->tr->wsp("hide").$this->h->input("checkbox","hide_".$line['ID'],"on",$hideParams);
			$hide .= $this->h->input("hidden","oldhide_".$line['ID'],$line['HIDE']);
			$modify = $this->h->ahref("admin.php?action=modify_article&amp;art=".$line['ID'],$this->tr->w("modify"));
			$view = $this->h->ahref("index.php?art=".$line['ID'],$this->tr->w("view"),"target=_blank");
			$subject = " \"".$this->h->short($line['SUBJECT'],60)."\"";
			$delete = $this->tr->w("delete").$this->h->input("checkbox","delete_".$line['ID'],"on");
			$artId = sprintf("%04d",$line['ID']);
			$content = $artId." | ".$date." | ".$hide." ".$modify." ".$delete." ".$view." | ".$this->h->span($subject,"style=\"color:green\"")." ".$user." ".$page;
			$artList .= $this->h->p($content);
		}
		$nextPages = $this->h->p($this->next_pages());
		$artList = $artListSubmit.$artList.$nextPages.$artListSubmit;
		$result .= $this->h->form($artList,"articles","post","admin.php?action=articles&amp;pg=".$this->pagePos);
		return $result;
	}
	public function next_pages(){
		$queryLevel1 = 	"SELECT COUNT(ID) AS NUM FROM ".ARTICLES;
		$queryLevel2 = 	"SELECT COUNT(".ARTICLES.".ID) AS NUM FROM ".ARTICLES.",".USERS." WHERE ".ARTICLES.".USERID = ".USERS.".ID AND ".USERS.".USERLEVEL > 1 ";
		$queryLevel3 = 	"SELECT COUNT(ID) AS NUM FROM ".ARTICLES." WHERE USERID = ".$_SESSION['userid'];
		$queryLevel4 =	$queryLevel3;
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3,$queryLevel4);
		$query = $this->q($queries[$_SESSION['level']]);
		$line = mysql_fetch_assoc($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=articles");
		$result = $this->h->p($pagesNumbers->numbers());
		return $result;
	}
}
?>

==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin_articles.php <==
<?php
class Articles extends Admin {
	function __construct() {
		$this->pagePos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->h = New Html();
		$this->tr = New Translate();
	}
	private function sortArticleBy() {
        $_SESSION['admin_article_sort'] = isset($_POST['sort'])?$_POST['sort']: 1;
        $result = 1;
		switch ($_SESSION['admin_article_sort']) {
			case 1:
				$result = ARTICLES.".DATE DESC";
				break;
			case 2:
				$result = ARTICLES.".SUBJECT";
				break;
			case 3:
				$result = ARTICLES.".PAGEID";
				break;
			case 4:
				$result = ARTICLES.".USERID";;   
				break;
		}
		return $result;
	}
	public function update_articles() {
		// empty form
		if (count($_POST) == 1) return;
		
		$values = $_POST;
		foreach($values as $k=>$v) {
			if ( preg_match("/\_/",$k) ) {
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value) {
			$query = 0;
			if (isset($value['delete'])) {
				$query = "DELETE FROM ".ARTICLES." WHERE ID = ".$id;
				$query = $this->q($query);
			}
			if (isset($value['hide']) && $value['oldhide'] == 0) {
				$query = "UPDATE ".ARTICLES." SET HIDE = 1 WHERE ID = ".$id;
				$query = $this->q($query);
			} else if (!isset($value['hide']) && $value['oldhide'] == 1) {
				$query = "UPDATE ".ARTICLES." SET HIDE = 0 WHERE ID = ".$id;
				$query = $this->q($query);
			}
		}
		$result = "";
		return $result;
	}
	public function list_articles($pgPos) {
		if ($pgPos) $pgPos = ($pgPos - 1) * ADMINITEMSBYPAGE;
		$siteDat = $this->home_params();
        
        if (isset($_GET['ownerFilter'])){
            $_SESSION['admin_articles_filter'] = ARTICLES.".USERID = ".$_GET['ownerFilter']." AND ";
        }
        
        if (isset($_GET['pageFilter'])){
            $_SESSION['admin_articles_filter'] = ARTICLES.".PAGEID = ".$_GET['pageFilter']." AND ";
        }
        
        if (isset($_POST['sort']) && $_POST['sort'] == 5) {
            if (isset($_SESSION['admin_articles_filter'])) {$_SESSION['admin_articles_filter'] = "";}
            if (isset($_SESSION['admin_article_sort'])) {$_SESSION['admin_article_sort'] = 1;}
        }
        
        $owners = array();
		$query = $this->q("SELECT ID,USERNAME FROM ".USERS);
		while ( $line = @mysql_fetch_assoc($query) ) {
			$owners[$line['USERNAME']] = $line['ID'];
		}
        
        $pages = array();
		$query = $this->q("SELECT ID,NAME FROM ".PAGES);
		while ( $line = @mysql_fetch_assoc($query) ) {
			$pages[$line['NAME']] = $line['ID'];
		}
        // $this->h->print_rr($owners);
        
		if (isset($_POST['search'])) {
			$queryLevel1 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							"MATCH(".ARTICLES.".SUBJECT) AGAINST('".$this->h->safe($_POST['search'])."') ".
							" ORDER BY ".ARTICLES.".SUBJECT LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							USERS.".USERLEVEL >= ".$_SESSION['level']." AND ".
							" MATCH(".ARTICLES.".SUBJECT) AGAINST('".$this->h->safe($_POST['search'])."') ".
							" ORDER BY ".ARTICLES.".SUBJECT LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".PAGES.".NAME FROM ".ARTICLES.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							"MATCH(".ARTICLES.".SUBJECT) AGAINST('".$this->h->safe($_POST['search'])."') ".
							" ORDER BY ".ARTICLES.".SUBJECT LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel4 = 	"SELECT ID,SUBJECT,DATE,HIDE FROM ".ARTICLES." WHERE ".
							ARTICLES.".PAGEID = ".$siteDat['SANDBOXID']." AND ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							"MATCH(".ARTICLES.".SUBJECT) AGAINST('".$this->h->safe($_POST['search'])."') ".
							" ORDER BY ".ARTICLES.".SUBJECT LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
        } else if (isset($_SESSION['admin_articles_filter']) && $_SESSION['admin_articles_filter'] != ""){
			$queryLevel1 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
                            $_SESSION['admin_articles_filter'].
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID".
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
                            $_SESSION['admin_articles_filter'].
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							USERS.".USERLEVEL >= ".$_SESSION['level'].
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".PAGES.".NAME FROM ".ARTICLES.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID".
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel4 = 	"SELECT ID,SUBJECT,DATE,HIDE FROM ".ARTICLES." WHERE ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							ARTICLES.".PAGEID = ".$siteDat['SANDBOXID']." ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} else {
			$queryLevel1 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID".
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel2 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".USERS.".USERNAME,".PAGES.".NAME FROM ".ARTICLES.",".USERS.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".USERS.".ID AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID AND ".
							USERS.".USERLEVEL >= ".$_SESSION['level'].
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel3 = 	"SELECT DISTINCT ".ARTICLES.".ID,".ARTICLES.".SUBJECT,".ARTICLES.".DATE,".ARTICLES.".HIDE,".PAGES.".NAME FROM ".ARTICLES.",".PAGES.
							" WHERE ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							ARTICLES.".PAGEID = ".PAGES.".ID".
							" ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			$queryLevel4 = 	"SELECT ID,SUBJECT,DATE,HIDE FROM ".ARTICLES." WHERE ".
							ARTICLES.".USERID = ".$_SESSION['userid']." AND ".
							ARTICLES.".PAGEID = ".$siteDat['SANDBOXID']." ORDER BY ".$this->sortArticleBy()." LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		}
		
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3,$queryLevel4);
		$query = $queries[$_SESSION['level']];
		$query = $this->q($query);
		$modified = isset($_POST['update'])?$this->tr->w(", (some values have been modified !)"):null;
		$result = $this->h->h3($this->tr->w("articles list").$modified);
		
		$sort = array($this->tr->w("date")=>1,$this->tr->w("subject")=>2,$this->tr->w("page")=>3,$this->tr->w("user")=>4,$this->tr->w("no filters")=>5);
		$type = isset($_POST['sort'])?$_POST['sort']:1;
		$sortForm = $this->h->p($this->h->select($sort,"sort",$type)." ".$this->h->input("submit","",$this->tr->w("sort/group by")));
		$result .= $this->h->form($sortForm,"sort","post","admin.php?action=articles");
		
		$resetForm = $this->h->p($this->h->input("submit","",$this->tr->w("no filters")).$this->h->input("hidden","sort",5));
		$result .= $this->h->form($resetForm,"reset","post","admin.php?action=articles");
        
        $searchForm = $this->h->p($this->h->input("submit","",$this->tr->w("search subject"))." ".$this->h->input("text","search",""));
		$result .= $this->h->form($searchForm,"search","post","admin.php?action=articles");
		
		$artListSubmit = $this->h->p($this->h->input("submit","",$this->tr->w("update all")));
		$artList = $this->h->input("hidden","update",1);
		while ( $line = mysql_fetch_assoc($query) ) {
			$user = isset($line['USERNAME'])?$this->tr->w("by-").$this->h->ahref("admin.php?action=articles&amp;ownerFilter=".$owners[$line['USERNAME']],$line['USERNAME']):null;
			$page = isset($line['NAME'])?" in page ".$this->h->ahref("admin.php?action=articles&amp;pageFilter=".$pages[$line['NAME']],$line['NAME']):$this->tr->wsp("{page-SandBox}");
			$date = $line['DATE'];
			$hideParams = ($line['HIDE'])?" checked=\"checked\"":null;
			$hide = $this->tr->wsp("hide").$this->h->input("checkbox","hide_".$line['ID'],"on",$hideParams);
			$hide .= $this->h->input("hidden","oldhide_".$line['ID'],$line['HIDE']);
			$modify = $this->h->ahref("admin.php?action=modify_article&amp;art=".$line['ID'],$this->tr->w("modify"));
			$view = $this->h->ahref("index.php?art=".$line['ID'],$this->tr->w("view"),"target=_blank");
			$subject = " \"".$this->h->short($line['SUBJECT'],60)."\"";
			$delete = $this->tr->w("delete").$this->h->input("checkbox","delete_".$line['ID'],"on");
			$artId = sprintf("%04d",$line['ID']);
			$content = $artId." | ".$date." | ".$hide." ".$modify." ".$delete." ".$view." | ".$this->h->span($subject,"style=\"color:green\"")." ".$user." ".$page;
			$artList .= $this->h->p($content);
		}
		$nextPages = $this->h->p($this->next_pages());
		$artList = $artListSubmit.$artList.$nextPages.$artListSubmit;
		$result .= $this->h->form($artList,"articles","post","admin.php?action=articles&amp;pg=".$this->pagePos);
		return $result;
	}
	public function next_pages(){
		$queryLevel1 = 	"SELECT COUNT(ID) AS NUM FROM ".ARTICLES;
		$queryLevel2 = 	"SELECT COUNT(".ARTICLES.".ID) AS NUM FROM ".ARTICLES.",".USERS." WHERE ".ARTICLES.".USERID = ".USERS.".ID AND ".USERS.".USERLEVEL > 1 ";
		$queryLevel3 = 	"SELECT COUNT(ID) AS NUM FROM ".ARTICLES." WHERE USERID = ".$_SESSION['userid'];
		$queryLevel4 =	$queryLevel3;
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3,$queryLevel4);
		$query = $this->q($queries[$_SESSION['level']]);
		$line = mysql_fetch_assoc($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=articles");
		$result = $this->h->p($pagesNumbers->numbers());
		return $result;
	}
}
?>
